//	Application Programming Interface (API) for ACRViewer
//	
//	Jens Breitenborn, 95/05/02
//

// The ACRViewer class implements a distributed objects interface
// to the ACRViewer application.

// Method description:
// -------------------
//
// - init
//		Launches ACRViewer and establishes the distributed objects connection.
//		It's necessary that ACRViewer is located in a place known by
//		WorkspaceManager. (/LocalApps , ~/Apps)
//
// - (BOOL) openACRFile:(const char*) filename
//		Opens the ACR/NEMA file given by file name in ACRViewer
//
// - (BOOL) openACRDirectory:(const char*) path
//		Opens path as Directory in ACRViewer. Path is scanned for
//		ACR/NEMA files.
//
// - (BOOL) setParameters:(const char*) parameters 
//          forOperator:(const char*) operatorName;
//      A parameter list (example: "Low=10;High= 250") is passed to the
//      Image Operator with name operatorName. 
//      For each "Parameter" in this list, -setParameter:toValue: of the
//      corresponding operator will be invoked. (see ImageOperator.h)
//
// - (BOOL) useOperator:(const char*) operatorName;
//      Activates the corresponding operator (either modifying or
//      non-modifying). If operatorName equals "" (empty string)
//      the currently active modifying operator will be deactivated.
//
// - (BOOL) convertACRFile:(const char*) inFilename 
//		 	toTiff:(const char*) outFilename;
//      The ACR/NEMA file specified by inFilename is opened in ACRViewer.
//      ACRViewer will convert this file into a TIFF file (outFilename).
//
//	- (BOOL) convertACRFile:(const char*) infilename 
//           toTiff:(const char*) outfilename
//           usingOperator:(const char*) operatorName
//           withParameters:(const char*) parameters;
//		Like simple conversion. But the image operator given by 
//      operatorName is applied to the image. Parameters for the image
//      operator are stored in parameters. (see setParameters:forOperator:)
	

// Notes:
//
// If a file name is not absolute, it will be considered relative to
// the executing processes working directory.
//
// A BOOL return value signals successful operation (YES) or failure (NO)
//


#import <appkit/appkit.h>

@interface ACRViewer:Object
{
	id		acrviewer;
}
- init;

- (BOOL) openACRFile:(const char*) filename;

- (BOOL) openACRDirectory:(const char*) path;

- (BOOL) setParameters:(const char*) parameters 
         forOperator:(const char*) operatorName;

- (BOOL) useOperator:(const char*) operatorName;

- (BOOL) convertACRFile:(const char*) inFilename 
		 toTiff:(const char*) outFilename;
		 
- (BOOL) convertACRFile:(const char*) infilename 
         toTiff:(const char*) outfilename
		 usingOperator:(const char*) operatorName
		 withParameters:(const char*) parameters;
		 
@end
